"use strict";
/**
 * @dev Class for managing random numbers
 * @dev In the Umbra Protocol, all random numbers should be 32 bytes to ensure sufficient security
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RandomNumber = void 0;
const ethers_1 = require("../ethers");
const secp256k1_1 = require("@noble/secp256k1");
class RandomNumber {
    /**
     * @notice Generate a new 32 byte random number
     */
    constructor() {
        this.sizeInBytes = 32; // generated random number will always be 32 bytes
        // Randomly generate 32 bytes and save them as a BigNumber
        const randomNumberAsBytes = secp256k1_1.utils.randomPrivateKey();
        this.value = ethers_1.BigNumber.from(randomNumberAsBytes);
    }
    /**
     * @notice Get random number as hex string
     */
    get asHex() {
        return (0, ethers_1.hexZeroPad)(this.value.toHexString(), this.sizeInBytes);
    }
    /**
     * @notice Get random number as hex string without 0x prefix
     */
    get asHexSlim() {
        return (0, ethers_1.hexZeroPad)(this.asHex, this.sizeInBytes).slice(2);
    }
}
exports.RandomNumber = RandomNumber;
//# sourceMappingURL=RandomNumber.js.map