"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TxHistoryProvider = void 0;
const ethers_1 = require("../ethers");
let _isCommunityResource = false;
class TxHistoryProvider extends ethers_1.EtherscanProvider {
    constructor(chainId, apiKey) {
        const _chainId = ethers_1.BigNumber.from(chainId).toNumber();
        if (!apiKey)
            _isCommunityResource = true;
        let defaultApiKey;
        switch (_chainId) {
            case 1: // mainnet
                defaultApiKey = process.env.ETHERSCAN_API_KEY;
                break;
            case 10: // optimism
                defaultApiKey = process.env.OPTIMISTIC_ETHERSCAN_API_KEY;
                break;
            case 100: // gnosis
                defaultApiKey = process.env.GNOSISSCAN_API_KEY;
                break;
            case 137: // polygon
                defaultApiKey = process.env.POLYGONSCAN_API_KEY;
                break;
            case 42161: // arbitrum
                defaultApiKey = process.env.ARBISCAN_API_KEY;
                break;
            case 11155111: // sepolia
                defaultApiKey = process.env.ETHERSCAN_API_KEY;
                break;
            default:
                throw new Error(`Unsupported chain ID ${_chainId}`);
        }
        super(_chainId, apiKey || defaultApiKey);
    }
    getBaseUrl() {
        switch (ethers_1.BigNumber.from(this.network.chainId).toNumber()) {
            case 1:
                return 'https://api.etherscan.io';
            case 10:
                return 'https://api-optimistic.etherscan.io';
            case 100:
                return 'https://api.gnosisscan.io';
            case 137:
                return 'https://api.polygonscan.com';
            case 42161:
                return 'https://api.arbiscan.io';
            case 11155111:
                return 'https://api-sepolia.etherscan.io';
        }
        throw new Error(`Unsupported network ${JSON.stringify(this.network.chainId)}`);
    }
    isCommunityResource() {
        return _isCommunityResource;
    }
}
exports.TxHistoryProvider = TxHistoryProvider;
//# sourceMappingURL=TxHistoryProvider.js.map