import { BigNumber, BigNumberish, ExternalProvider as EthersExternalProvider, JsonRpcFetchFunc, StaticJsonRpcProvider, Overrides, Web3Provider } from './ethers';
export { TransactionResponse } from './ethers';
import { TransactionResponse } from './ethers';
export type ExternalProvider = EthersExternalProvider | JsonRpcFetchFunc;
export type EthersProvider = Web3Provider | StaticJsonRpcProvider;
export interface TransactionResponseExtended extends TransactionResponse {
    arbSubType?: number;
    arbType?: number;
    indexInParent?: number;
    l1BlockNumber?: number;
    l1SequenceNumber?: string;
    parentRequestId?: string;
    index?: number;
    l1Timestamp?: number;
    l1TxOrigin?: string | null;
    queueIndex?: number | null;
    queueOrigin?: string;
    rawTransaction?: string;
    transactionIndex?: number;
    [key: string]: any;
}
export interface ChainConfig {
    chainId: number;
    umbraAddress: string;
    batchSendAddress: string | null;
    startBlock: number;
    subgraphUrl: string | false;
}
export interface EncryptedPayload {
    ephemeralPublicKey: string;
    ciphertext: string;
}
export interface CompressedPublicKey {
    prefix: number;
    pubKeyXCoordinate: string;
}
export interface SendOverrides extends Overrides {
    advanced?: boolean;
    supportPubKey?: boolean;
    supportTxHash?: boolean;
}
export interface ScanOverrides {
    startBlock?: number | string;
    endBlock?: number | string;
}
export interface Announcement {
    amount: BigNumber;
    ciphertext: string;
    pkx: string;
    receiver: string;
    token: string;
}
export interface AnnouncementDetail {
    amount: BigNumber;
    ciphertext: string;
    pkx: string;
    receiver: string;
    token: string;
    block: string;
    from: string;
    timestamp: string;
    txHash: string;
}
export interface SubgraphAnnouncement {
    amount: string;
    block: string;
    ciphertext: string;
    from: string;
    id: string;
    pkx: string;
    receiver: string;
    timestamp: string;
    token: string;
    txHash: string;
}
export interface UserAnnouncement {
    amount: BigNumber;
    from: string;
    isWithdrawn: boolean;
    randomNumber: string;
    receiver: string;
    timestamp: string;
    token: string;
    txHash: string;
}
export interface SubgraphStealthKeyChangedEvent {
    block: string;
    from: string;
    id: string;
    registrant: string;
    spendingPubKeyPrefix: BigNumber;
    spendingPubKey: BigNumber;
    timestamp: string;
    txHash: string;
    viewingPubKeyPrefix: BigNumber;
    viewingPubKey: BigNumber;
}
export interface SendBatch {
    token: string;
    amount: BigNumberish;
    address: string;
}
export interface SendData {
    receiver: string;
    tokenAddr: string;
    amount: BigNumberish;
    pkx: string;
    ciphertext: string;
}
export type GraphFilterOverride = {
    startBlock?: number | string;
    endBlock?: number | string;
    registrant?: string;
};
//# sourceMappingURL=types.d.ts.map