/**
 * @dev Functions for interacting with the Ethereum Name Service (ENS)
 */
import { EthersProvider } from '../types';
import { Contract } from '../ethers';
/**
 * @notice Returns the address of the ENS stealth key resolver to use based on the provider's network
 * @param name ENS domain, e.g. myname.eth
 * @param provider Ethers provider
 */
export declare const getResolverContract: (name: string, provider: EthersProvider) => Promise<Contract>;
/**
 * @notice Computes ENS namehash of the input ENS domain, normalized to ENS compatibility
 * @param name ENS domain, e.g. myname.eth
 */
export declare function namehash(name: string): string;
/**
 * @notice For a given ENS domain, returns the public keys, or throws if they don't exist
 * @param name ENS domain, e.g. myname.eth
 * @param provider Ethers provider
 */
export declare function getPublicKeys(name: string, provider: EthersProvider): Promise<{
    spendingPublicKey: string;
    viewingPublicKey: string;
}>;
//# sourceMappingURL=ens.d.ts.map